webStyle property
bool
get
webStyle
If you want to use the style for web when you are on the web, use true.
Implementation
bool get webStyle => DesignTypeScope.of(this).webStyle;
If you want to use the style for web when you are on the web, use true.
bool get webStyle => DesignTypeScope.of(this).webStyle;